# Python-KSEF documentation


!!! warning "Warning"
    
    This Library is not yet production ready. It is in early alpha development right now.

A python library for Polish KSEF (National e-invoice system, original: Krajowy System e-Faktur) system.
